@@ -7,7 +7,7 @@ from djeese.utils import check_urls
 import os
 
 
-VALID_TYPES = ['string', 'stringtuplelist', 'stringlist', 'boolean']
+VALID_TYPES = ['string', 'stringtuplelist', 'stringlist', 'boolean', 'integer']
 REQUIRED_APP_KEYS = ['name', 'packagename', 'installed-apps', 'description',
                      'license', 'url', 'version', 'private']
 DEPRECATION_APP_KEYS = {
